@@ -31,7 +31,7 @@ POE::Session->create(
 			my ($kernel, $heap) = @_[KERNEL, HEAP];
 			if ($_[ARG1]) {
 				print "opened ".ref($_[ARG1])."\n";
-				$kernel->post(njb => 'track_list');
+				$kernel->post(njb => 'track_list' => $ARGV[0]);
 			} else {
 				$kernel->post(njb => 'shutdown');
 			}
